const gulp = require('gulp');
const babel = require('gulp-babel');
const concat = require('gulp-concat');
const uglify = require('gulp-uglify');
const umd = require('gulp-umd');
const mocha = require('gulp-mocha');
const requirejsOptimize = require('gulp-requirejs-optimize');
const sourcemaps = require('gulp-sourcemaps');
const del = require('del');
const path = require('path');
const rename = require('gulp-rename');
const root = path.join(__dirname);
const node_modules = path.join(root, 'node_modules');

const paths = {
    scripts: [
        'node_modules/almond/almond.js',
        'src/main.js'
    ],
    watch: [
        'src/*.js'
    ]
};

gulp.task('clean', function () {
    return del(['dist']);
});

gulp.task('scripts', ['clean'], function () {
    return gulp.src(paths.scripts)
        //.pipe(sourcemaps.init())
        .pipe(requirejsOptimize({
            optimize: 'none'
        }))
        .pipe(concat('browser-detect.js'))
        .pipe(babel({
            "plugins": [
                "check-es2015-constants",
                "transform-es2015-arrow-functions",
                "transform-es2015-block-scoped-functions",
                "transform-es2015-block-scoping",
                "transform-es2015-classes",
                "transform-es2015-computed-properties",
                "transform-es2015-destructuring",
                "transform-es2015-duplicate-keys",
                "transform-es2015-for-of",
                //"transform-es2015-function-name"
                "transform-es2015-literals",
                "transform-es2015-modules-commonjs",
                "transform-es2015-object-super",
                "transform-es2015-parameters",
                "transform-es2015-shorthand-properties",
                "transform-es2015-spread",
                "transform-es2015-sticky-regex",
                "transform-es2015-template-literals",
                "transform-es2015-typeof-symbol",
                "transform-es2015-unicode-regex",
                "transform-regenerator"
            ]
        }))
        .pipe(umd({
            namespace: function(file) {
                return 'browser';
            },
            template: path.join(root, 'templates/returnExports.js')
        }))
        .pipe(gulp.dest('dist'))
        .pipe(uglify())
        //.pipe(sourcemaps.write())
        .pipe(rename('browser-detect.min.js'))
        .pipe(gulp.dest('dist'));
});

gulp.task('watch', function () {
    gulp.watch(paths.watch, ['scripts']);
});


gulp.task('test', ['scripts'], function () {
    gulp.src("./test/unit/", {read:false}).pipe(mocha({reporter:'spec'}));
});

gulp.task('default', ['scripts']);